---
name: Feature Request
about: Requesting new features to be added to either Raiden backend or UI
---

## Abstract

Please describe by example what problem you see in the current Raiden Network implementation that you would like addressed.

## Motivation

In this section please describe how you propose to address the problem you described earlier. Try to include example use cases that showcase the value of your proposal.

## Specification

If the feature is technical in nature please write as detailed as possible a specification of what needs to be built.

## Backwards Compatibility

If the feature is technical in nature and introduces changes to the Raiden Protocol, then please use this section to describe how backwards compatibility with the previous version of the protocol can be achieved.
